@@ -40,9 +40,9 @@
 
 
 #include <kgamepopupitem.h>
-#include <kicon.h>
-#include <klocale.h>
-#include <kpushbutton.h>
+#include <QIcon>
+#include <KLocalizedString>
+#include <QPushButton>
 
 
 #include "kbbballsonboard.h"
@@ -86,7 +86,7 @@ KBBScalableGraphicWidget::KBBScalableGraphicWidget(KBBGameDoc* gameDoc, KBBTheme
 	m_blackbox->setKBBScalableGraphicWidget(this);
 	m_balls = new KBBGraphicsItemSet(m_scene);
 	m_cursor = new KBBGraphicsItemCursor(this, m_themeManager);
-	connect(m_cursor, SIGNAL(cursorAtNewPosition(int)), this, SLOT(cursorAtNewPosition(int)));
+	connect(m_cursor, &KBBGraphicsItemCursor::cursorAtNewPosition, this, &KBBScalableGraphicWidget::cursorAtNewPosition);
 	m_markersNothing = new KBBGraphicsItemSet(m_scene);
 	m_ballsSolution = new KBBGraphicsItemSet(m_scene);
 	m_ballsUnsure = new KBBGraphicsItemSet(m_scene);
@@ -105,10 +105,10 @@ KBBScalableGraphicWidget::KBBScalableGraphicWidget(KBBGameDoc* gameDoc, KBBTheme
 
 	setScene(m_scene);
 
-	m_doneButton = new KPushButton(m_doneAction->text(), this);
-	m_doneButton->setIcon(KIcon(m_doneAction->icon()));
+	m_doneButton = new QPushButton(m_doneAction->text(), this);
+	m_doneButton->setIcon(QIcon(m_doneAction->icon()));
 	m_doneButton->setWhatsThis(m_doneAction->whatsThis());
-	connect(m_doneButton, SIGNAL(clicked(bool)), m_doneAction, SLOT(trigger()));
+	connect(m_doneButton, &QPushButton::clicked, m_doneAction, &QAction::trigger);
 	QFont font;
 	font.setPointSize(m_doneButton->font().pointSize()+2);
 	font.setBold(true);
@@ -542,7 +542,7 @@ void KBBScalableGraphicWidget::switchBall()
 {
 	if ((m_balls->containsVisible(m_cursor->boxPosition())) || (m_ballsUnsure->containsVisible(m_cursor->boxPosition())))
 		removeBall(m_cursor->boxPosition());
-	else
+	else if (m_ballRepository->ballToTake() != KBBGraphicsItemSet::NO_INDEX)
 		addBall(m_cursor->boxPosition());
 }
 
@@ -594,11 +594,11 @@ void KBBScalableGraphicWidget::useLaser(const int incomingPosition)
 		m_scene->update();
 		m_lasers->setVisible(incomingPosition, false);
 
-		popupText(""); // To Remove any displayed text quicker.
+        popupText(QString()); // To Remove any displayed text quicker.
 
 		cursorAtNewPosition(incomingPosition);
 	}
 }
 
 
-#include "kbbscalablegraphicwidget.moc"
+
